@@ -13,13 +13,14 @@ from scipy import ndimage
 import cv2
 from stardist.models import StarDist2D
 
-import skimage.io
-from stardist.models import StarDist3D
+# import skimage.io
+# from stardist.models import StarDist3D
 from csbdeep.utils import normalize
 from naparimovie import Movie
 import math
 import gc
 
+
 class NapariSTPT:
 
     def __init__(self):
@@ -44,10 +45,9 @@ class NapariSTPT:
         self.maxSizeN = None
         self.thresholdN = None
         self.slice_names = None
-        
+
         self.align_x = None
         self.align_y = None
-        #self.spacing = None
         self.ds1 = None
         self.im1 = None
         self.im32 = None
@@ -83,9 +83,7 @@ class NapariSTPT:
         volume = volume[minX:maxX, minY:maxY, minZ:maxZ]
 
         return volume
-
-    
-
+        
     def Load(self, text):
         # global self.ds1
         # global ds
@@ -124,22 +122,22 @@ class NapariSTPT:
         except Exception:
             print("none-consolidated")
             self.ds1 = xr.open_zarr(self.search_folder.text() +
-                               str(self.comboBoxPath.currentText())+'/mos.zarr')
+                                    str(self.comboBoxPath.currentText())+'/mos.zarr')
         # ds2 = xr.open_zarr(str(self.comboBoxPath.currentText())+'/mos.zarr', group='l.2')
         # ds4 = xr.open_zarr(str(self.comboBoxPath.currentText())+'/mos.zarr', group='l.4')
         # ds8 = xr.open_zarr(str(self.comboBoxPath.currentText())+'/mos.zarr', group='l.8')
         # ds32 = xr.open_zarr(str(self.comboBoxPath.currentText())+'/mos.zarr', group='l.32')
 
         self.slice_names = self.ds1.attrs['cube_reg']['slice']
-        #print(self.slice_names)
+        # print(self.slice_names)
 
         bscale = self.ds1.attrs['bscale']
         bzero = self.ds1.attrs['bzero']
 
-        #print(self.ds1.attrs.keys())
-        #print(self.ds1.attrs)
-        #print(self.ds1['S001'].attrs.keys())
-        #print(self.ds1['S001'].attrs)
+        # print(self.ds1.attrs.keys())
+        # print(self.ds1.attrs)
+        # print(self.ds1['S001'].attrs.keys())
+        # print(self.ds1['S001'].attrs)
         # print(self.ds1.attrs["multiscale"]['datasets'][1]['level'])
         # print(self.ds1.attrs["multiscale"]['datasets'][1]['path'])
 
@@ -152,7 +150,8 @@ class NapariSTPT:
         resolution = int(self.comboBoxResolution.currentText())
         print("loading at resolution {}".format(resolution))
         index = self.comboBoxResolution.currentIndex()
-        print("group: " + self.ds1.attrs["multiscale"]['datasets'][index]['path'])
+        print("group: " +
+              self.ds1.attrs["multiscale"]['datasets'][index]['path'])
         gr = self.ds1.attrs["multiscale"]['datasets'][index]['path']
         ds = xr.open_zarr(self.search_folder.text(
         ) + str(self.comboBoxPath.currentText())+'/mos.zarr', group=gr)
@@ -165,153 +164,187 @@ class NapariSTPT:
 
         output_resolution = float(self.pixel_size.text())
 
-
         with napari.gui_qt():
             if self.cb_C1.isChecked():
                 print("loading C1")
-                volume_1_temp = (ds.sel(channel=1, type='mosaic', z=0).to_array().data * bscale + bzero).astype(dtype=np.float32)
+                volume_1_temp = (ds.sel(channel=1, type='mosaic', z=0).to_array(
+                ).data * bscale + bzero).astype(dtype=np.float32)
 
                 if self.crop:
-                    size_y = int(math.floor(volume_1_temp.shape[1]/self.crop_size_ratio_x))
-                    size_z = int(math.floor(volume_1_temp.shape[2]/self.crop_size_ratio_y))
-                    start_y = int(math.floor(volume_1_temp.shape[1]/self.crop_start_ratio_x))
-                    start_z = int(math.floor(volume_1_temp.shape[2]/self.crop_start_ratio_y))
+                    size_y = int(math.floor(
+                        volume_1_temp.shape[1]/self.crop_size_ratio_x))
+                    size_z = int(math.floor(
+                        volume_1_temp.shape[2]/self.crop_size_ratio_y))
+                    start_y = int(math.floor(
+                        volume_1_temp.shape[1]/self.crop_start_ratio_x))
+                    start_z = int(math.floor(
+                        volume_1_temp.shape[2]/self.crop_start_ratio_y))
                 else:
                     size_y = int(math.floor(volume_1_temp.shape[1]))
                     size_z = int(math.floor(volume_1_temp.shape[2]))
                     start_y = 0
                     start_z = 0
 
-                volume_1 = np.zeros((self.optical_slices*volume_1_temp.shape[0],size_y,size_z), dtype=np.float32)
-                volume_1[0::self.optical_slices,:,:] = volume_1_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
+                volume_1 = np.zeros(
+                    (self.optical_slices*volume_1_temp.shape[0], size_y, size_z), dtype=np.float32)
+                volume_1[0::self.optical_slices, :, :] = volume_1_temp[:,
+                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
 
                 for optical_slice in range(1, self.optical_slices):
                     print(f"loading optical slice {optical_slice}")
-                    volume_1_temp = (ds.sel(channel=1, type='mosaic', z=optical_slice).to_array().data * bscale + bzero).astype(dtype=np.float32)
-                    volume_1[optical_slice::self.optical_slices,:,:] = volume_1_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
-                
-                #self.aligned_1 = volume_1
+                    volume_1_temp = (ds.sel(channel=1, type='mosaic', z=optical_slice).to_array(
+                    ).data * bscale + bzero).astype(dtype=np.float32)
+                    volume_1[optical_slice::self.optical_slices, :, :] = volume_1_temp[:,
+                                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
+
+                # self.aligned_1 = volume_1
 
                 print("aligning C1")
                 self.aligned_1 = self.Align(
                     volume_1, resolution, output_resolution)
                 self.shape = self.aligned_1.shape
                 self.viewer.add_image([self.aligned_1], name='C1', scale=(
-                    15/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='bop purple', translate=(0, int(start_y*output_resolution),int(start_z*output_resolution)))
+                    15/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='bop purple', translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
             if self.cb_C2.isChecked():
                 print("loading C2")
 
-                volume_2_temp = (ds.sel(channel=2, type='mosaic', z=0).to_array().data * bscale + bzero).astype(dtype=np.float32)
+                volume_2_temp = (ds.sel(channel=2, type='mosaic', z=0).to_array(
+                ).data * bscale + bzero).astype(dtype=np.float32)
 
                 if self.crop:
-                    size_y = int(math.floor(volume_2_temp.shape[1]/self.crop_size_ratio_x))
-                    size_z = int(math.floor(volume_2_temp.shape[2]/self.crop_size_ratio_y))
-                    start_y = int(math.floor(volume_2_temp.shape[1]/self.crop_start_ratio_x))
-                    start_z = int(math.floor(volume_2_temp.shape[2]/self.crop_start_ratio_y))
+                    size_y = int(math.floor(
+                        volume_2_temp.shape[1]/self.crop_size_ratio_x))
+                    size_z = int(math.floor(
+                        volume_2_temp.shape[2]/self.crop_size_ratio_y))
+                    start_y = int(math.floor(
+                        volume_2_temp.shape[1]/self.crop_start_ratio_x))
+                    start_z = int(math.floor(
+                        volume_2_temp.shape[2]/self.crop_start_ratio_y))
                 else:
                     size_y = int(math.floor(volume_2_temp.shape[1]))
                     size_z = int(math.floor(volume_2_temp.shape[2]))
                     start_y = 0
                     start_z = 0
 
-                volume_2 = np.zeros((self.optical_slices*volume_2_temp.shape[0],size_y,size_z), dtype=np.float32)
-                volume_2[0::self.optical_slices,:,:] = volume_2_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
+                volume_2 = np.zeros(
+                    (self.optical_slices*volume_2_temp.shape[0], size_y, size_z), dtype=np.float32)
+                volume_2[0::self.optical_slices, :, :] = volume_2_temp[:,
+                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
 
                 for optical_slice in range(1, self.optical_slices):
                     print(f"loading optical slice {optical_slice}")
-                    volume_2_temp = (ds.sel(channel=2, type='mosaic', z=optical_slice).to_array().data * bscale + bzero).astype(dtype=np.float32)
-                    volume_2[optical_slice::self.optical_slices,:,:] = volume_2_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
-                
-                #self.aligned_2 = volume_2
-                
+                    volume_2_temp = (ds.sel(channel=2, type='mosaic', z=optical_slice).to_array(
+                    ).data * bscale + bzero).astype(dtype=np.float32)
+                    volume_2[optical_slice::self.optical_slices, :, :] = volume_2_temp[:,
+                                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
+
+                # self.aligned_2 = volume_2
+
                 print("aligning C2")
                 self.aligned_2 = self.Align(
                     volume_2, resolution, output_resolution)
                 self.shape = self.aligned_2.shape
                 self.viewer.add_image([self.aligned_2], name='C2', scale=(
-                    15.0/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='red', translate=(0, int(start_y*output_resolution),int(start_z*output_resolution)))
+                    15.0/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='red', translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
             if self.cb_C3.isChecked():
                 print("loading C3")
-                volume_3_temp = (ds.sel(channel=3, type='mosaic', z=0).to_array().data * bscale + bzero).astype(dtype=np.float32)
+                volume_3_temp = (ds.sel(channel=3, type='mosaic', z=0).to_array(
+                ).data * bscale + bzero).astype(dtype=np.float32)
 
                 if self.crop:
-                    size_y = int(math.floor(volume_3_temp.shape[1]/self.crop_size_ratio_x))
-                    size_z = int(math.floor(volume_3_temp.shape[2]/self.crop_size_ratio_y))
-                    start_y = int(math.floor(volume_3_temp.shape[1]/self.crop_start_ratio_x))
-                    start_z = int(math.floor(volume_3_temp.shape[2]/self.crop_start_ratio_y))
+                    size_y = int(math.floor(
+                        volume_3_temp.shape[1]/self.crop_size_ratio_x))
+                    size_z = int(math.floor(
+                        volume_3_temp.shape[2]/self.crop_size_ratio_y))
+                    start_y = int(math.floor(
+                        volume_3_temp.shape[1]/self.crop_start_ratio_x))
+                    start_z = int(math.floor(
+                        volume_3_temp.shape[2]/self.crop_start_ratio_y))
                 else:
                     size_y = int(math.floor(volume_3_temp.shape[1]))
                     size_z = int(math.floor(volume_3_temp.shape[2]))
                     start_y = 0
                     start_z = 0
 
-                volume_3 = np.zeros((self.optical_slices*volume_3_temp.shape[0],size_y,size_z), dtype=np.float32)
-                volume_3[0::self.optical_slices,:,:] = volume_3_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
+                volume_3 = np.zeros(
+                    (self.optical_slices*volume_3_temp.shape[0], size_y, size_z), dtype=np.float32)
+                volume_3[0::self.optical_slices, :, :] = volume_3_temp[:,
+                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
 
                 for optical_slice in range(1, self.optical_slices):
                     print(f"loading optical slice {optical_slice}")
-                    volume_3_temp = (ds.sel(channel=3, type='mosaic', z=optical_slice).to_array().data * bscale + bzero).astype(dtype=np.float32)
-                    volume_3[optical_slice::self.optical_slices,:,:] = volume_3_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
-                
-                #self.aligned_3 = volume_3
+                    volume_3_temp = (ds.sel(channel=3, type='mosaic', z=optical_slice).to_array(
+                    ).data * bscale + bzero).astype(dtype=np.float32)
+                    volume_3[optical_slice::self.optical_slices, :, :] = volume_3_temp[:,
+                                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
+
+                # self.aligned_3 = volume_3
 
                 print("aligning C3")
                 self.aligned_3 = self.Align(
                     volume_3, resolution, output_resolution)
                 self.shape = self.aligned_3.shape
                 self.viewer.add_image([self.aligned_3], name='C3', scale=(
-                    15/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='green', translate=(0, int(start_y*output_resolution),int(start_z*output_resolution)))
+                    15/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='green', translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
             if self.cb_C4.isChecked():
                 print("loading C4")
-                volume_4_temp = (ds.sel(channel=4, type='mosaic', z=0).to_array().data * bscale + bzero).astype(dtype=np.float32)
+                volume_4_temp = (ds.sel(channel=4, type='mosaic', z=0).to_array(
+                ).data * bscale + bzero).astype(dtype=np.float32)
 
                 if self.crop:
-                    size_y = int(math.floor(volume_4_temp.shape[1]/self.crop_size_ratio_x))
-                    size_z = int(math.floor(volume_4_temp.shape[2]/self.crop_size_ratio_y))
-                    start_y = int(math.floor(volume_4_temp.shape[1]/self.crop_start_ratio_x))
-                    start_z = int(math.floor(volume_4_temp.shape[2]/self.crop_start_ratio_y))
+                    size_y = int(math.floor(
+                        volume_4_temp.shape[1]/self.crop_size_ratio_x))
+                    size_z = int(math.floor(
+                        volume_4_temp.shape[2]/self.crop_size_ratio_y))
+                    start_y = int(math.floor(
+                        volume_4_temp.shape[1]/self.crop_start_ratio_x))
+                    start_z = int(math.floor(
+                        volume_4_temp.shape[2]/self.crop_start_ratio_y))
                 else:
                     size_y = int(math.floor(volume_4_temp.shape[1]))
                     size_z = int(math.floor(volume_4_temp.shape[2]))
                     start_y = 0
                     start_z = 0
 
-                volume_4 = np.zeros((self.optical_slices*volume_4_temp.shape[0],size_y,size_z), dtype=np.float32)
-                volume_4[0::self.optical_slices,:,:] = volume_4_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
+                volume_4 = np.zeros(
+                    (self.optical_slices*volume_4_temp.shape[0], size_y, size_z), dtype=np.float32)
+                volume_4[0::self.optical_slices, :, :] = volume_4_temp[:,
+                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
 
                 for optical_slice in range(1, self.optical_slices):
                     print(f"loading optical slice {optical_slice}")
-                    volume_4_temp = (ds.sel(channel=4, type='mosaic', z=optical_slice).to_array().data * bscale + bzero).astype(dtype=np.float32)
-                    volume_4[optical_slice::self.optical_slices,:,:] = volume_4_temp[:,start_y:start_y+size_y,start_z:start_z+size_z]
-                
-                #self.aligned_4 = volume_4
+                    volume_4_temp = (ds.sel(channel=4, type='mosaic', z=optical_slice).to_array(
+                    ).data * bscale + bzero).astype(dtype=np.float32)
+                    volume_4[optical_slice::self.optical_slices, :, :] = volume_4_temp[:,
+                                                                                       start_y:start_y+size_y, start_z:start_z+size_z]
+
+                # self.aligned_4 = volume_4
 
                 print("aligning C4")
                 self.aligned_4 = self.Align(
                     volume_4, resolution, output_resolution)
                 self.shape = self.aligned_4.shape
                 self.viewer.add_image([self.aligned_4], name='C4', scale=(
-                    15/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='bop blue', translate=(0, int(start_y*output_resolution),int(start_z*output_resolution)))
+                    15/self.optical_slices, output_resolution, output_resolution), blending='additive', colormap='bop blue', translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
-            #create naparimovie object
-            if self.movie == None:
+            # create naparimovie object
+            if self.movie is None:
                 self.movie = Movie(myviewer=self.viewer)
                 self.movie.inter_steps = 30
 
-
     def LoadInRegion(self, text):
 
         print(self.viewer.layers.selected[0].data)
-        l = len(self.viewer.layers.selected[0].data[0])
-        print(l)
+        data_length = len(self.viewer.layers.selected[0].data[0])
+        print(data_length)
         minX = 100000000
         maxX = 0
         minY = 100000000
         maxY = 0
-        for i in range(0, l):
+        for i in range(0, data_length):
             print(self.viewer.layers.selected[0].data[0][i])
             if minX > self.viewer.layers.selected[0].data[0][i][1]:
                 minX = self.viewer.layers.selected[0].data[0][i][1]
@@ -344,7 +377,7 @@ class NapariSTPT:
             self.crop_size_ratio_y = self.aligned_4.shape[2]/(maxY-minY)
 
         self.viewer.layers.remove('Shapes')
-        #print("crop to: {} {} {} {}".format(minX, maxX, minY, maxY))
+        # print("crop to: {} {} {} {}".format(minX, maxX, minY, maxY))
 
         self.crop = True
 
@@ -356,7 +389,7 @@ class NapariSTPT:
               str(self.comboBoxPath.currentText()) + '/mos.zarr')
 
         self.ds1 = xr.open_zarr(self.search_folder.text() +
-                           str(self.comboBoxPath.currentText())+'/mos.zarr')
+                                str(self.comboBoxPath.currentText())+'/mos.zarr')
         ds2 = xr.open_zarr(self.search_folder.text(
         ) + str(self.comboBoxPath.currentText())+'/mos.zarr', group='l.2')
         ds4 = xr.open_zarr(self.search_folder.text(
@@ -491,7 +524,7 @@ class NapariSTPT:
             slice_name = self.slice_names[z]
 
             spacing = (self.ds1[slice_name].attrs['scale'])
-            # print(spacing)
+            print(f"spacing {spacing}")
             # fixed.SetSpacing([1.6*spacing[0],1.6*spacing[1]])
             fixed.SetSpacing([resolution*0.1*spacing[1],
                              resolution*0.1*spacing[0]])
@@ -799,19 +832,18 @@ class NapariSTPT:
             self.viewer.add_image([self.aligned_4], name='C4', scale=(
                 15, output_resolution, output_resolution), blending='additive', colormap='bop blue')
 
-
     def CropToRegion(self):
 
         output_resolution = float(self.pixel_size.text())
 
         print(self.viewer.layers.selected[0].data)
-        l = len(self.viewer.layers.selected[0].data[0])
-        print(l)
+        data_length = len(self.viewer.layers.selected[0].data[0])
+        print(data_length)
         minX = 100000000
         maxX = 0
         minY = 100000000
         maxY = 0
-        for i in range(0, l):
+        for i in range(0, data_length):
             print(self.viewer.layers.selected[0].data[0][i])
             if minX > self.viewer.layers.selected[0].data[0][i][1]:
                 minX = self.viewer.layers.selected[0].data[0][i][1]
@@ -824,29 +856,30 @@ class NapariSTPT:
 
         print("crop to: {} {} {} {}".format(minX, maxX, minY, maxY))
 
-
         if self.aligned_1 is not None and self.cb_C1.isChecked() and any(i.name == 'C1' for i in self.viewer.layers):
-            self.aligned_1 = self.aligned_1[:, int(minX):int(maxX), int(minY):int(maxY)]
+            self.aligned_1 = self.aligned_1[:, int(
+                minX):int(maxX), int(minY):int(maxY)]
             self.viewer.layers.remove('C1')
             self.viewer.add_image([self.aligned_1], name='C1', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='bop purple', translate=(0, int(minX*output_resolution),int(minY*output_resolution)))
+                15, output_resolution, output_resolution), blending='additive', colormap='bop purple', translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
         if self.aligned_2 is not None and self.cb_C2.isChecked() and any(i.name == 'C2' for i in self.viewer.layers):
-            self.aligned_2 = self.aligned_2[:, int(minX):int(maxX), int(minY):int(maxY)]
+            self.aligned_2 = self.aligned_2[:, int(
+                minX):int(maxX), int(minY):int(maxY)]
             self.viewer.layers.remove('C2')
             self.viewer.add_image([self.aligned_2], name='C2', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='red', translate=(0, int(minX*output_resolution),int(minY*output_resolution)))
+                15, output_resolution, output_resolution), blending='additive', colormap='red', translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
         if self.aligned_3 is not None and self.cb_C3.isChecked() and any(i.name == 'C3' for i in self.viewer.layers):
-            self.aligned_3 = self.aligned_3[:, int(minX):int(maxX), int(minY):int(maxY)]
+            self.aligned_3 = self.aligned_3[:, int(
+                minX):int(maxX), int(minY):int(maxY)]
             self.viewer.layers.remove('C3')
             self.viewer.add_image([self.aligned_3], name='C3', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='green', translate=(0, int(minX*output_resolution),int(minY*output_resolution)))
+                15, output_resolution, output_resolution), blending='additive', colormap='green', translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
         if self.aligned_4 is not None and self.cb_C4.isChecked() and any(i.name == 'C4' for i in self.viewer.layers):
-            self.aligned_4 = self.aligned_4[:, int(minX):int(maxX), int(minY):int(maxY)]
+            self.aligned_4 = self.aligned_4[:, int(
+                minX):int(maxX), int(minY):int(maxY)]
             self.viewer.layers.remove('C4')
             self.viewer.add_image([self.aligned_4], name='C4', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='bop blue', translate=(0, int(minX*output_resolution),int(minY*output_resolution)))
-
-
+                15, output_resolution, output_resolution), blending='additive', colormap='bop blue', translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
 
     def SelectFolder(self):
         file = str(QtWidgets.QFileDialog.getExistingDirectory())
@@ -904,20 +937,19 @@ class NapariSTPT:
         value = self.scroll.value()
         self.image_slice.setText(str(value))
 
-
     def run_stardist(self):
         print("run_stardist")
 
         print(self.viewer.layers.selected[0].data)
-        #print()
+        # print()
 
-        l = len(self.viewer.layers.selected[0].data[0])
-        print(l)
+        data_length = len(self.viewer.layers.selected[0].data[0])
+        print(data_length)
         minX = 100000000
         maxX = 0
         minY = 100000000
         maxY = 0
-        for i in range(0, l):
+        for i in range(0, data_length):
             print(self.viewer.layers.selected[0].data[0][i])
             if minX > self.viewer.layers.selected[0].data[0][i][0]:
                 minX = self.viewer.layers.selected[0].data[0][i][0]
@@ -929,16 +961,15 @@ class NapariSTPT:
                 maxY = self.viewer.layers.selected[0].data[0][i][1]
 
         print("{} {} {} {}".format(minX, maxX, minY, maxY))
-        #return
-        # prints a list of available models 
-        StarDist2D.from_pretrained() 
+        # return
+        # prints a list of available models
+        StarDist2D.from_pretrained()
 
         # creates a pretrained model
         model = StarDist2D.from_pretrained('2D_versatile_fluo')
 
         # import image
-        #image = skimage.io.imread('H:/GitRepositories/STPT/crop.tif')
-
+        # image = skimage.io.imread('H:/GitRepositories/STPT/crop.tif')
 
         bscale = self.ds1.attrs['bscale']
         bzero = self.ds1.attrs['bzero']
@@ -954,121 +985,101 @@ class NapariSTPT:
 
         slice_name = self.slice_names[z]
 
-
-        #print(image.shape)
-        #print(type(image))
-        #return
+        # print(image.shape)
+        # print(type(image))
+        # return
         # normalize image
-        im12 = self.ds1[slice_name].sel( channel=2, type='mosaic', z=0).data * bscale + bzero
+        im12 = self.ds1[slice_name].sel(
+            channel=2, type='mosaic', z=0).data * bscale + bzero
         im12 = np.array(im12[int(minX):int(maxX), int(minY):int(maxY)])
-        im13 = self.ds1[slice_name].sel( channel=3, type='mosaic', z=0).data * bscale + bzero
+        im13 = self.ds1[slice_name].sel(
+            channel=3, type='mosaic', z=0).data * bscale + bzero
         im13 = np.array(im13[int(minX):int(maxX), int(minY):int(maxY)])
 
-        #img = np.array(im1[(im1.shape[0]/2)-1000:(im1.shape[0]/2)+1000,(im1.shape[1]/2)-1000:(im1.shape[1]/2)+1000,])
+        # img = np.array(im1[(im1.shape[0]/2)-1000:(im1.shape[0]/2)+1000,(im1.shape[1]/2)-1000:(im1.shape[1]/2)+1000,])
 
         img = im12 - ((0.128 * im13) + 17.371)
 
         print(type(img))
         print(img.shape)
 
-        #img = np.array(im1[(im1.shape[0]/2)-1000:(im1.shape[0]/2)+1000,(im1.shape[1]/2)-1000:(im1.shape[1]/2)+1000,])
-        #print(type(img))
-        #print(img.shape)
-       
-        img = normalize(img, 1,99.8, axis=(0,1))
-        #return
+        # img = np.array(im1[(im1.shape[0]/2)-1000:(im1.shape[0]/2)+1000,(im1.shape[1]/2)-1000:(im1.shape[1]/2)+1000,])
+        # print(type(img))
+        # print(img.shape)
+
+        img = normalize(img, 1, 99.8, axis=(0, 1))
+        # return
         # predict segmentation
-        labels, details = model.predict_instances(img, n_tiles=(10,10))
-        #print(details['points'])
+        labels, details = model.predict_instances(img, n_tiles=(10, 10))
+        # print(details['points'])
 
+        # with napari.gui_qt():
+        self.viewer.add_image(
+            img, name='img', blending='additive', translate=(int(minX), int(minY)))
 
-        #with napari.gui_qt():
-        self.viewer.add_image(img, name='img', blending='additive', translate=(int(minX),int(minY)))
-
-        self.viewer.add_image(im12, name='im12', blending='additive', translate=(int(minX),int(minY)))
-        self.viewer.add_image(im13, name='im13', blending='additive', translate=(int(minX),int(minY)))
-        self.viewer.add_labels(labels, name='labels', blending='additive', translate=(int(minX),int(minY)))
-        self.viewer.add_points(details['points'], translate=(int(minX),int(minY)))
+        self.viewer.add_image(
+            im12, name='im12', blending='additive', translate=(int(minX), int(minY)))
+        self.viewer.add_image(
+            im13, name='im13', blending='additive', translate=(int(minX), int(minY)))
+        self.viewer.add_labels(
+            labels, name='labels', blending='additive', translate=(int(minX), int(minY)))
+        self.viewer.add_points(
+            details['points'], translate=(int(minX), int(minY)))
 
     def SaveMovie(self):
-        
-        widget = QtWidgets.QWidget()
-        fname = QtWidgets.QFileDialog.getSaveFileName(widget, 'Save file as', 'c:\\',"Image files (*.gif *.mp4)")
 
-        if isinstance(fname,tuple):
+        widget = QtWidgets.QWidget()
+        fname = QtWidgets.QFileDialog.getSaveFileName(
+            widget, 'Save file as', 'c:\\', "Image files (*.gif *.mp4)")
+
+        if isinstance(fname, tuple):
             print(fname[0])
             filename, file_extension = os.path.splitext(fname[0])
             if file_extension == '.mp4':
-                self.movie.make_movie(name = 'movie.mp4', resolution = 300, fps = 20)
+                self.movie.make_movie(name='movie.mp4', resolution=300, fps=20)
             if file_extension == '.gif':
                 self.movie.make_gif('S:/Tristan/gifmovie.gif')
 
     def SaveVolume(self):
         widget = QtWidgets.QWidget()
-        fname = QtWidgets.QFileDialog.getSaveFileName(widget, 'Save file as', 'c:\\',"Image files (*.tiff *.mha)")
+        fname = QtWidgets.QFileDialog.getSaveFileName(
+            widget, 'Save file as', 'c:\\', "Image files (*.tiff *.mha)")
 
-        if isinstance(fname,tuple):
+        if isinstance(fname, tuple):
             print(fname[0])
 
             output_resolution = float(self.pixel_size.text())
-            spacing = (output_resolution, output_resolution, 15/self.optical_slices)
-
-            #volume_2 = 5000 * (volume_2 / np.max(volume_2))
-            #volume_2 = np.clip(volume_2, 0, 255)
-            #volume_2 = np.round(volume_2)
-            #volume_2 = volume_2.astype(np.ubyte)
-
-            #volume_3 = 5000 * (volume_3 / np.max(volume_3))
-            #volume_3 = np.clip(volume_3, 0, 255)
-            #volume_3 = np.round(volume_3)
-            #volume_3 = volume_3.astype(np.ubyte)
-
-            #volume_4 = np.zeros_like(volume_2)
-            #volume = np.stack((volume_2, volume_3), axis=3)
-            #volume = np.concatenate((volume, np.expand_dims(volume_4, axis=3)), axis=3)
-
-            #rgbImage_itk = sitk.GetImageFromArray(volume, isVector=True)
-            #rgbImage_itk.SetSpacing(spacing)
-            #sitk.WriteImage(rgbImage_itk, "S:/Tristan/RGB.tif")
-
-            
-            #aligned_4 = np.zeros_like(self.aligned_2)
-            #volume = np.stack((self.aligned_2, self.aligned_3), axis=3)
-            #volume = np.concatenate((volume, np.expand_dims(aligned_4, axis=3)), axis=3)
-
-
-            #if self.aligned_1 != None:
-            #    volume = np.zeros_like(self.aligned_1)
-            #elif self.aligned_2 != None:
-            #    volume = np.zeros_like(self.aligned_2)
-            #elif self.aligned_2 != None:
-           #     volume = np.zeros_like(self.aligned_2)
-            #elif self.aligned_3 != None:
-            #    volume = np.zeros_like(self.aligned_3)
+            spacing = (output_resolution, output_resolution,
+                       15/self.optical_slices)
 
+            # Not the most efficinet method
             volume = np.zeros(self.shape)
             volume = np.expand_dims(volume, axis=3)
-                
+
             print(f"volume {volume.shape}")
             try:
-                volume = np.concatenate((volume, np.expand_dims(self.aligned_1, axis=3)), axis=3)
+                volume = np.concatenate(
+                    (volume, np.expand_dims(self.aligned_1, axis=3)), axis=3)
             except Exception:
                 pass
             try:
-                volume = np.concatenate((volume, np.expand_dims(self.aligned_2, axis=3)), axis=3)
+                volume = np.concatenate(
+                    (volume, np.expand_dims(self.aligned_2, axis=3)), axis=3)
             except Exception:
                 pass
             try:
-                volume = np.concatenate((volume, np.expand_dims(self.aligned_3, axis=3)), axis=3)
+                volume = np.concatenate(
+                    (volume, np.expand_dims(self.aligned_3, axis=3)), axis=3)
             except Exception:
                 pass
             try:
-                volume = np.concatenate((volume, np.expand_dims(self.aligned_4, axis=3)), axis=3)
+                volume = np.concatenate(
+                    (volume, np.expand_dims(self.aligned_4, axis=3)), axis=3)
             except Exception:
                 pass
 
             print(f"volume {volume.shape}")
-                
+
             volume = np.delete(volume, 0, 3)
 
             print(f"volume {volume.shape}")
@@ -1080,11 +1091,8 @@ class NapariSTPT:
             volume_itk = caster.Execute(volume_itk)
             sitk.WriteImage(volume_itk, fname[0])
 
-
-    
     def main(self):
 
-
         with napari.gui_qt():
 
             self.viewer = napari.Viewer()
@@ -1120,6 +1128,7 @@ class NapariSTPT:
             self.comboBoxPath.currentIndexChanged.connect(
                 self.on_combobox_changed)
             hbox.addWidget(self.comboBoxPath)
+            hbox.addStretch(1)
             vbox.addLayout(hbox)
 
             hbox = QtWidgets.QHBoxLayout()
@@ -1138,14 +1147,14 @@ class NapariSTPT:
             vbox.addLayout(hbox)
 
             hbox = QtWidgets.QHBoxLayout()
-            hbox.addWidget(QtWidgets.QLabel("Maximum number of optical slices:"))
+            hbox.addWidget(QtWidgets.QLabel(
+                "Maximum number of optical slices:"))
             self.nr_optical_slices = QtWidgets.QLineEdit("1")
             self.nr_optical_slices.setMaximumWidth(50)
             hbox.addWidget(self.nr_optical_slices)
             hbox.addStretch(1)
             vbox.addLayout(hbox)
 
-
             hbox = QtWidgets.QHBoxLayout()
             hbox.addWidget(QtWidgets.QLabel("Load channels:"))
             self.cb_C1 = QtWidgets.QCheckBox('1')
@@ -1164,18 +1173,22 @@ class NapariSTPT:
             vbox.addLayout(hbox)
 
             hbox = QtWidgets.QHBoxLayout()
-            bLoad3D = QtWidgets.QPushButton('Load image 3D')
+            bLoad3D = QtWidgets.QPushButton('Load volume')
             bLoad3D.setCheckable(True)
             bLoad3D.clicked.connect(self.Load)
             hbox.addWidget(bLoad3D)
-            #hbox.addStretch(1)
-            #vbox.addLayout(hbox)
+            # hbox.addStretch(1)
+            # vbox.addLayout(hbox)
 
-            #hbox = QtWidgets.QHBoxLayout()
-            bLoad3D = QtWidgets.QPushButton('Reload image 3D in region')
+            # hbox = QtWidgets.QHBoxLayout()
+            bLoad3D = QtWidgets.QPushButton('Reload in shape')
             bLoad3D.setCheckable(True)
             bLoad3D.clicked.connect(self.LoadInRegion)
             hbox.addWidget(bLoad3D)
+            bCrop = QtWidgets.QPushButton('Crop to shape')
+            bCrop.setCheckable(True)
+            bCrop.clicked.connect(self.CropToRegion)
+            hbox.addWidget(bCrop)
             hbox.addStretch(1)
             vbox.addLayout(hbox)
 
@@ -1210,14 +1223,10 @@ class NapariSTPT:
             bRemoveN.setCheckable(True)
             bRemoveN.clicked.connect(self.Remove_Small_Regions)
             hbox.addWidget(bRemoveN)
-            bCrop = QtWidgets.QPushButton('Crop')
-            bCrop.setCheckable(True)
-            bCrop.clicked.connect(self.CropToRegion)
-            hbox.addWidget(bCrop)
             hbox.addStretch(1)
             vbox.addLayout(hbox)
 
-            bLoad2D = QtWidgets.QPushButton('Load image 2D')
+            bLoad2D = QtWidgets.QPushButton('Load slice')
             bLoad2D.setCheckable(True)
             bLoad2D.clicked.connect(self.Load2D)
             hbox = QtWidgets.QHBoxLayout()
@@ -1241,8 +1250,6 @@ class NapariSTPT:
             widget.setLayout(vbox)
             self.viewer.window.add_dock_widget(widget, area="right")
 
-
-
             bSaveVolume = QtWidgets.QPushButton('Save volume')
             bSaveVolume.setCheckable(True)
             bSaveVolume.clicked.connect(self.SaveVolume)
@@ -1253,20 +1260,19 @@ class NapariSTPT:
             bSaveMovie.setCheckable(True)
             bSaveMovie.clicked.connect(self.SaveMovie)
             hbox.addWidget(bSaveMovie)
+            hbox.addStretch(1)
             vbox.addLayout(hbox)
 
-
-            bStardist = QtWidgets.QPushButton('Run Stardist')
+            bStardist = QtWidgets.QPushButton('Run Stardist in shape')
             bStardist.setCheckable(True)
             bStardist.clicked.connect(self.run_stardist)
             hbox = QtWidgets.QHBoxLayout()
             hbox.addWidget(bStardist)
+            hbox.addStretch(1)
             vbox.addLayout(hbox)
 
-            
             vbox.addStretch(1)
 
-
             # inputfile = ''
             # try:
             #     opts, args = getopt.getopt(
